@@ -130,7 +130,7 @@ class GoldenTestCase(UCTestCase):
         raise NotImplementedError()
 
 
-class ExecutableGoldenTestCase(GoldenTestCase):
+class ExecutableTestCase(UCTestCase):
     def execute(self, parameters, exe, path="/autograder/source/build/"):
         args = [path + exe]
         args.extend(parameters)
@@ -141,8 +141,10 @@ class ExecutableGoldenTestCase(GoldenTestCase):
         exe.terminate()
         return output
 
+class ExecutableGoldenTestCase(ExecutableTestCase, GoldenTestCase):
+    pass
 
-class InteractiveExecutableGoldenTestCase(GoldenTestCase):
+class InteractiveExecutableTestCase(UCTestCase):
     def execute(self, parameters, exe, inputs, path="/autograder/source/build/"):
         args = [path + exe]
         args.extend(parameters)
@@ -157,3 +159,6 @@ class InteractiveExecutableGoldenTestCase(GoldenTestCase):
         output = exe.stdout.read()
         exe.terminate()
         return output
+
+class InteractiveExecutableGoldenTestCase(InteractiveExecutableTestCase, GoldenTestCase):
+    pass
\ No newline at end of file
